@@ -33,38 +33,34 @@
 #include "nis_passwd.h"
 
 
-void nis_setpwent(void)
+void nis_setpwent(char *opts)
 {
 }
 
 
-void nis_endpwent(void)
+void nis_endpwent(char *opts)
 {
 }
 
 
-struct passwd *nis_getpwent(void)
+struct passwd *nis_getpwent(char *opts)
 {
+    errno = ECONNREFUSED;
+    return NULL;
 }
 
 
-struct passwd *nis_getpwuid(uid_t uid)
+struct passwd *nis_getpwuid(uid_t uid, char *opts)
 {
+    errno = ECONNREFUSED;
+    return NULL;
 }
 
 
-struct passwd *nis_getpwnam(char *name)
+struct passwd *nis_getpwnam(char *name, char *opts)
 {
-    if (strcmp(name, "pen2") == 0)
-	return getpwnam("jan");
-    else
-    {
-	if (strcmp(name, "pen3") == 0)
-	    errno = ECONNREFUSED;
-	
-	return NULL;
-    }
+    errno = ECONNREFUSED;
+    return NULL;
 }
 
-
 #endif /* ENABLE_NIS */
