@@ -29,11 +29,11 @@
 #include <pwd.h>
 #include <sys/types.h>
 
-extern void nis_setpwent(void);
-extern void nis_endpwent(void);
-extern struct passwd *nis_getpwent(void);
-extern struct passwd *nis_getpwuid(uid_t uid);
-extern struct passwd *nis_getpwnam(char *name);
+extern void nis_setpwent(char *opts);
+extern void nis_endpwent(char *opts);
+extern struct passwd *nis_getpwent(char *opts);
+extern struct passwd *nis_getpwuid(uid_t uid, char *opts);
+extern struct passwd *nis_getpwnam(char *name, char *opts);
 
 #endif
 
