@@ -32,12 +32,12 @@ main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    nis_setpwent();
+    nis_setpwent(NULL);
 
-    while (pw = nis_getpwent())
+    while (pw = nis_getpwent(NULL))
 	print_passwd(pw);
 
-    nis_endpwent();
+    nis_endpwent(NULL);
     
     exit(0);
 }
