@@ -29,11 +29,11 @@
 #include <sys/types.h>
 #include <pwd.h>
 
-extern void yp_setpwent(void);
-extern void yp_endpwent(void);
-extern struct passwd *yp_getpwent(void);
-extern struct passwd *yp_getpwuid(uid_t uid);
-extern struct passwd *yp_getpwnam(char *name);
+extern void yp_setpwent(char *opts);
+extern void yp_endpwent(char *opts);
+extern struct passwd *yp_getpwent(char *opts);
+extern struct passwd *yp_getpwuid(uid_t uid, char *opts);
+extern struct passwd *yp_getpwnam(char *name, char *opts);
 
 #endif
 
