@@ -32,7 +32,7 @@ main(int argc, char *argv[])
     struct passwd *pw;
 
 
-    pw = yp_getpwuid(atoi(argv[1]));
+    pw = yp_getpwuid(atoi(argv[1]), NULL);
 
     if (pw)
 	print_passwd(pw);
